#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# imports.
from netw0rk.v1.classes.config import *
from netw0rk.v1.classes import utils

# the network object class.
class Network(object):
	def __init__(self):

		# variables.
		self._info_ = None
		self.api_key = None

		#
	def info(self):

		# get info.
		info = None
		if self.api_key == None: 
			info = requests.get('https://ipinfo.io/json').json()
		else: 
			info = requests.get('https://ipinfo.io/json', headers={'Authorization': 'Bearer {}'.format(self.api_key)}).json()
		try: 
			error = info["error"]
			return r3sponse.error_response(f"(https://ipinfo.io/json) {error['title']}: {error['message']}")
		except KeyError: a=1

		# set.
		try: 
			x = info["ip"]
			del(info["ip"])
			info["public_ip"] = x
		except KeyError: 
			return r3sponse.error_response("Unable to fetch netork info.")
		try: info["private_ip"] = self.__get_private_ip__()
		except: info["private_ip"] = "unkown"
		try: info["hostname"] = socket.gethostname()
		except: info["hostname"] = "unkown"

		# success.
		return r3sponse.success_response(f"Successfully retrieved the network information.", info)

		#
	def convert_dns(self, dns, timeout=3):
		response = self.ping(dns, timeout=timeout)
		if response["error"] != None: return response
		if response["ip"] == None: 
			return r3sponse.error_response(f"Failed to convert dns [{dns}].")
		return r3sponse.success_response(f"Successfully converted dns [{dns}].", {
			"ip":response["ip"]
		})
	def ping(self, ip, timeout=3):

		# set info.
		info = {
			"ip":None,
			"up":False,
		}

		# execute.
		output = utils.__execute__(["ping", ip], timeout=timeout, return_format="string")

		# handle.
		info["dns"] = ip
		try: info["ip"] = output.split(f"PING {ip} (")[1].split("):")[0]
		except: info["ip"] = None
		if "Request timeout for" in output:
			response["up"] = False
		elif " info from " in output:
			info["up"] = True
		else: 
			return r3sponse.error_response(f"Unknown output: {output}")

		# success.
		return r3sponse.success_response(f"Successfully pinged [{ip}].", info)

		#
	# system functions.
	def __get_private_ip__(self):
		s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
		try:
			# doesn't even have to be reachable
			s.connect(('10.255.255.255', 1))
			ip = s.getsockname()[0]
		except Exception:
			ip = '127.0.0.1'
		finally:
			s.close()
		return ip


# initialized classes.
network = Network()

"""

# get network info.
response = network.info("vandenberghinc.com")

# ping an ip.
response = network.ping("192.168.1.200")

# convert a dns.
response = network.convert_dns("vandenberghinc.com")

"""



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# imports.
from netw0rk.v1.classes.config import *
from netw0rk.v1.classes import utils

# the curl object class.
class Curl(object):
	def __init__(self, 
		base_url=None,
		headers={},
	):

		#	-	init:
		if base_url[len(base_url)-1] != '/': base_url += '/'
		self.base_url = base_url
		self.headers = headers
	def download_img(self, url, img):
		url = self.base_url+url.replace('//','/')
		os.system('curl -s -o {url} "{img}"')
		if os.path.exists(img_path): return True
		else: return False
	def get(self, url, data=None):
		url = self.base_url+url.replace('//','/')
		if data == None: return requests.get(url, headers=self.headers).json()
		else: return requests.get(url, data=data, headers=self.headers).json()
	def post(self, url, data=None):
		url = self.base_url+url.replace('//','/')
		if data == None: return requests.post(url, headers=self.headers).json()
		else: return requests.post(url, json=data, headers=self.headers).json()
	def delete(self, url, data=None):
		url = self.base_url+url.replace('//','/')
		if data == None:  return requests.delete(url, headers=self.headers)
		else: return requests.delete(url, json=data, headers=self.headers)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# insert the package for universal imports.
import os, sys, syst3m

# settings.
SOURCE_NAME = "netw0rk"
VERSION = "v1"
SOURCE_PATH = syst3m.defaults.get_source_path(__file__, back=2)
BASE = syst3m.defaults.get_source_path(SOURCE_PATH, back=1)
sys.path.insert(1, BASE)

# imports.
import netw0rk
from netw0rk.v1.classes.config import *

# the cli object class.
class CLI(cl1.CLI):
	def __init__(self):
		
		# defaults.
		cl1.CLI.__init__(self,
			modes={
				"--network":"Access the network.",
				"    --info":"Retrieve the current network information.",
				"--firewall":"Access the firewall (Linux only).",
				"    --info":"Retrieve the current firewall information.",
				"    --disable":"Disable the firewall.",
				"    --enable":"Enable the firewall.",
				"    --set-default false":"Set the default firewall behaviour (deny/allow).",
				"    --allow 22":"Allow a port in the firewall settings.",
				"    --deny 22":"Deny a port in the firewall settings.",
				"-h / --help":"Show the documentation.",
			},
			options={
				"-c":"Do not clear the logs.",
			},
			alias=ALIAS,
			executable=__file__,
		)

		#
	def start(self):

		# clear logs.
		if not self.arguments_present(['-c']):
			os.system("clear")

		# help.
		if self.arguments_present(['-h', '--help']):
			print(self.documentation)

		# network.
		elif self.arguments_present(['--network']):

			# info.
			if self.arguments_present(['--info']):
				response = netw0rk.network.info()
				r3sponse.log(response=response)
				if r3sponse.success(response): 
					del response["message"] ; del response["error"] ; del response["success"]
					info = json.dumps(response, indent=0).replace("{\n","").replace("\n}","").replace('",',"").replace('"',"")
					print(info)


			# invalid.
			else:  self.invalid()

		# firewall.
		elif self.arguments_present(['--firewall']):

			# check os.
			syst3m.default.check_operating_system(supported=["linux"])

			# retrieve the firewall information.
			if self.arguments_present(['--info']):
				response = netw0rk.firewall.info()
				r3sponse.log(response=response)
				if r3sponse.success(response): 
					del response["message"] ; del response["error"] ; del response["success"]
					info = json.dumps(response, indent=0).replace("{\n","").replace("\n}","").replace('",',"").replace('"',"")
					print(info)

			# disable the firewall.
			elif self.arguments_present(['--disable']):
				response = netw0rk.firewall.disable()
				r3sponse.log(response=response)

			# enable the firewall.
			elif self.arguments_present(['--enable']):
				response = netw0rk.firewall.enable()
				r3sponse.log(response=response)

			# set the default port action.
			elif self.arguments_present(['--set-default']):
				deny = self.get_argument("--set-default")
				if deny in ["True", "true", True]: deny = True
				else: deny = False
				response = netw0rk.firewall.set_default(deny=deny)
				r3sponse.log(response=response)

			# allow a port.
			elif self.arguments_present(['--allow']):
				port = int(self.get_argument("--allow"))
				response = netw0rk.firewall.allow(port)
				r3sponse.log(response=response)

			# deny a port.
			elif self.arguments_present(['--deny']):
				port = int(self.get_argument("--deny"))
				response = netw0rk.firewall.deny(port)
				r3sponse.log(response=response)


			# invalid.
			else:  self.invalid()

		# invalid.
		else:  self.invalid()

		#
	def invalid(self):
		print(self.documentation)
		print("Selected an invalid mode.")
		sys.exit(1)
	
# main.
if __name__ == "__main__":
	cli = CLI()
	if "--developer" in sys.argv:
		cli.start()
	else:
		try:
			cli.start()
		except KeyboardInterrupt:
			print("Aborted: KeyboardInterrupt")

